@@ -6,11 +6,12 @@
 
 
 import os
-from z3c.sqlalchemy import createSAWrapper
-
 from config import WRAPPER_NAME
 from model import getModel
 
+from sqlalchemy import create_engine
+from sqlalchemy.engine.url import make_url
+
 
 def setup(dsn=None, echo=False):
 
@@ -19,12 +20,6 @@ def setup(dsn=None, echo=False):
         raise ValueError('$TESTING_DSN undefined or the [default]/dsn option of your '
                          'configuration file is not configured properly.')
 
-    wrapper = createSAWrapper(dsn,
-                              forZope=False,
-                              model=getModel,
-                              echo=echo,
-                              convert_unicode=False,
-                              name=WRAPPER_NAME)
-    return wrapper
-
-
+    engine = create_engine(dsn)
+    engine.url = make_url(dsn)
+    return engine
